@@ -7,15 +7,16 @@ import uuid
 
 from simplyblock_core import db_controller, constants, utils
 from simplyblock_core.controllers import tasks_events, device_controller
+from simplyblock_core.models.cluster import Cluster
 from simplyblock_core.models.job_schedule import JobSchedule
 from simplyblock_core.models.storage_node import StorageNode
 
 logger = logging.getLogger()
-db_controller = db_controller.DBController()
+db = db_controller.DBController()
 
 
 def _validate_new_task_dev_restart(cluster_id, node_id, device_id):
-    tasks = db_controller.get_job_tasks(cluster_id)
+    tasks = db.get_job_tasks(cluster_id)
     for task in tasks:
         if task.function_name == JobSchedule.FN_DEV_RESTART and task.device_id == device_id and task.canceled is False:
             if task.status != JobSchedule.STATUS_DONE:
@@ -29,7 +30,7 @@ def _validate_new_task_dev_restart(cluster_id, node_id, device_id):
 
 
 def _validate_new_task_node_restart(cluster_id, node_id):
-    tasks = db_controller.get_job_tasks(cluster_id)
+    tasks = db.get_job_tasks(cluster_id)
     for task in tasks:
         if task.function_name == JobSchedule.FN_NODE_RESTART and task.node_id == node_id:
             if task.status != JobSchedule.STATUS_DONE and task.canceled is False:
@@ -71,14 +72,14 @@ def _add_task(function_name, cluster_id, node_id, device_id,
         task_obj.function_params = function_params
     task_obj.max_retry = max_retry
     task_obj.status = JobSchedule.STATUS_NEW
-    task_obj.write_to_db(db_controller.kv_store)
+    task_obj.write_to_db(db.kv_store)
     tasks_events.task_create(task_obj)
     return task_obj.uuid
 
 
 def add_device_mig_task(device_id):
-    device = db_controller.get_storage_device_by_id(device_id)
-    for node in db_controller.get_storage_nodes_by_cluster_id(device.cluster_id):
+    device = db.get_storage_device_by_id(device_id)
+    for node in db.get_storage_nodes_by_cluster_id(device.cluster_id):
         if node.status == StorageNode.STATUS_REMOVED:
             continue
 
@@ -94,18 +95,28 @@ def add_device_to_auto_restart(device):
 
 
 def add_node_to_auto_restart(node):
+    cluster = db.get_cluster_by_id(node.cluster_id)
+    if cluster.status not in [Cluster.STATUS_ACTIVE, Cluster.STATUS_DEGRADED, Cluster.STATUS_READONLY]:
+        logger.warning(f"Cluster is not active, skip node auto restart, status: {cluster.status}")
+        return False
+    for sn in db.get_storage_nodes_by_cluster_id(node.cluster_id):
+        if node.get_id() != sn.get_id() and sn.status != StorageNode.STATUS_ONLINE and node.mgmt_ip != sn.mgmt_ip:
+            logger.info("Node found that is not online, skip node auto restart")
+            return False
     return _add_task(JobSchedule.FN_NODE_RESTART, node.cluster_id, node.get_id(), "")
 
 
-def list_tasks(cluster_id, is_json=False):
-    cluster = db_controller.get_cluster_by_id(cluster_id)
-    if not cluster:
+def list_tasks(cluster_id, is_json=False, limit=50, **kwargs):
+    try:
+        db.get_cluster_by_id(cluster_id)
+    except KeyError:
         logger.error("Cluster not found: %s", cluster_id)
         return False
 
     data = []
-    tasks = db_controller.get_job_tasks(cluster_id, reverse=False)
-    if tasks and is_json is True:
+    tasks = db.get_job_tasks(cluster_id, reverse=True, limit=limit)
+    tasks.reverse()
+    if is_json is True:
         for t in tasks:
             data.append(t.get_clean_dict())
         return json.dumps(data, indent=2)
@@ -137,7 +148,7 @@ def list_tasks(cluster_id, is_json=False):
 
 
 def cancel_task(task_id):
-    task = db_controller.get_task_by_id(task_id)
+    task = db.get_task_by_id(task_id)
     if not task:
         logger.error("Task not found: %s", task_id)
         return False
@@ -146,22 +157,22 @@ def cancel_task(task_id):
         device_controller.device_set_retries_exhausted(task.device_id, True)
 
     task.canceled = True
-    task.write_to_db(db_controller.kv_store)
+    task.write_to_db(db.kv_store)
     tasks_events.task_canceled(task)
     return True
 
 
 def get_active_node_restart_task(cluster_id, node_id):
-    tasks = db_controller.get_job_tasks(cluster_id)
+    tasks = db.get_job_tasks(cluster_id)
     for task in tasks:
         if task.function_name == JobSchedule.FN_NODE_RESTART and task.node_id == node_id:
-            if task.status == JobSchedule.STATUS_RUNNING and task.canceled is False:
+            if task.status != JobSchedule.STATUS_DONE and task.canceled is False:
                 return task.uuid
     return False
 
 
 def get_active_dev_restart_task(cluster_id, device_id):
-    tasks = db_controller.get_job_tasks(cluster_id)
+    tasks = db.get_job_tasks(cluster_id)
     for task in tasks:
         if task.function_name == JobSchedule.FN_DEV_RESTART and task.device_id == device_id:
             if task.status == JobSchedule.STATUS_RUNNING and task.canceled is False:
@@ -169,19 +180,23 @@ def get_active_dev_restart_task(cluster_id, device_id):
     return False
 
 
-def get_active_node_mig_task(cluster_id, node_id):
-    tasks = db_controller.get_job_tasks(cluster_id)
+def get_active_node_mig_task(cluster_id, node_id, distr_name=None):
+    tasks = db.get_job_tasks(cluster_id)
     for task in tasks:
         if task.function_name in [JobSchedule.FN_FAILED_DEV_MIG, JobSchedule.FN_DEV_MIG,
                                   JobSchedule.FN_NEW_DEV_MIG] and task.node_id == node_id:
             if task.status == JobSchedule.STATUS_RUNNING and task.canceled is False:
-                return task.uuid
+                if distr_name:
+                    if "distr_name" in task.function_params and task.function_params["distr_name"] == distr_name:
+                        return task.uuid
+                else:
+                    return task.uuid
     return False
 
 
 def add_device_failed_mig_task(device_id):
-    device = db_controller.get_storage_device_by_id(device_id)
-    for node in db_controller.get_storage_nodes_by_cluster_id(device.cluster_id):
+    device = db.get_storage_device_by_id(device_id)
+    for node in db.get_storage_nodes_by_cluster_id(device.cluster_id):
         if node.status == StorageNode.STATUS_REMOVED:
             continue
         for bdev in node.lvstore_stack:
@@ -192,8 +207,8 @@ def add_device_failed_mig_task(device_id):
 
 
 def add_new_device_mig_task(device_id):
-    device = db_controller.get_storage_device_by_id(device_id)
-    for node in db_controller.get_storage_nodes_by_cluster_id(device.cluster_id):
+    device = db.get_storage_device_by_id(device_id)
+    for node in db.get_storage_nodes_by_cluster_id(device.cluster_id):
         if node.status == StorageNode.STATUS_REMOVED:
             continue
         for bdev in node.lvstore_stack:
@@ -208,7 +223,7 @@ def add_node_add_task(cluster_id, function_params):
 
 
 def get_active_node_tasks(cluster_id, node_id):
-    tasks = db_controller.get_job_tasks(cluster_id)
+    tasks = db.get_job_tasks(cluster_id)
     out = []
     for task in tasks:
         if task.node_id == node_id:
@@ -218,7 +233,7 @@ def get_active_node_tasks(cluster_id, node_id):
 
 
 def get_new_device_mig_task(cluster_id, node_id, distr_name, dev_id=None):
-    tasks = db_controller.get_job_tasks(cluster_id)
+    tasks = db.get_job_tasks(cluster_id)
     for task in tasks:
         if task.function_name == JobSchedule.FN_NEW_DEV_MIG and task.node_id == node_id:
             if dev_id:
@@ -231,7 +246,7 @@ def get_new_device_mig_task(cluster_id, node_id, distr_name, dev_id=None):
 
 
 def get_device_mig_task(cluster_id, node_id, device_id, distr_name):
-    tasks = db_controller.get_job_tasks(cluster_id)
+    tasks = db.get_job_tasks(cluster_id)
     for task in tasks:
         if task.function_name == JobSchedule.FN_DEV_MIG and task.node_id == node_id and task.device_id == device_id:
             if task.status != JobSchedule.STATUS_DONE and task.canceled is False \
@@ -241,7 +256,7 @@ def get_device_mig_task(cluster_id, node_id, device_id, distr_name):
 
 
 def get_new_device_mig_task_for_device(cluster_id):
-    tasks = db_controller.get_job_tasks(cluster_id)
+    tasks = db.get_job_tasks(cluster_id)
     for task in tasks:
         if task.function_name == JobSchedule.FN_NEW_DEV_MIG:
             if task.status != JobSchedule.STATUS_DONE and task.canceled is False:
@@ -250,9 +265,13 @@ def get_new_device_mig_task_for_device(cluster_id):
 
 
 def get_failed_device_mig_task(cluster_id, device_id):
-    tasks = db_controller.get_job_tasks(cluster_id)
+    tasks = db.get_job_tasks(cluster_id)
     for task in tasks:
         if task.function_name == JobSchedule.FN_FAILED_DEV_MIG and task.device_id == device_id:
             if task.status != JobSchedule.STATUS_DONE and task.canceled is False:
                 return task.uuid
     return False
+
+
+def add_port_allow_task(cluster_id, node_id, port_number):
+    return _add_task(JobSchedule.FN_PORT_ALLOW, cluster_id, node_id, "", function_params={"port_number": port_number})
