@@ -14,6 +14,7 @@ class Cluster(BaseModel):
     STATUS_DEGRADED = "degraded"
     STATUS_UNREADY = "unready"
     STATUS_IN_ACTIVATION = "in_activation"
+    STATUS_IN_EXPANSION = "in_expansion"
 
     STATUS_CODE_MAP = {
         STATUS_ACTIVE: 1,
@@ -22,6 +23,9 @@ class Cluster(BaseModel):
 
         STATUS_SUSPENDED: 10,
         STATUS_DEGRADED: 11,
+        STATUS_UNREADY: 12,
+        STATUS_IN_ACTIVATION: 13,
+        STATUS_IN_EXPANSION: 14,
 
     }
 
@@ -43,6 +47,7 @@ class Cluster(BaseModel):
     enable_qos: bool = False
     grafana_endpoint: str = ""
     grafana_secret: str = ""
+    contact_point: str = ""
     ha_type: str = "single"
     inflight_io_threshold: int = 4
     iscsi: str = ""
@@ -54,9 +59,11 @@ class Cluster(BaseModel):
     prov_cap_warn: int = 180
     qpair_count: int = 32
     secret: str = ""
+    disable_monitoring: bool = False
     strict_node_anti_affinity: bool = False
     tls: bool = False
     is_re_balancing: bool = False
+    full_page_unmap: bool = True
 
     def get_status_code(self):
         if self.status in self.STATUS_CODE_MAP:
