@@ -48,8 +48,11 @@ class LVol(BaseModel):
     node_id: str = ""
     nodes: List[str] = []
     nqn: str = ""
-    nvme_dev: NVMeDevice = None
+    ns_id: int = 1
+    subsys_port: int = 9090
+    nvme_dev: NVMeDevice = None  # type: ignore[assignment]
     pool_uuid: str = ""
+    pool_name: str = ""
     pvc_name: str = ""
     r_mbytes_per_sec: int = 0
     rw_ios_per_sec: int = 0
@@ -59,3 +62,6 @@ class LVol(BaseModel):
     top_bdev: str = ""
     vuid: int = 0
     w_mbytes_per_sec: int = 0
+
+    def has_qos(self):
+        return (self.rw_ios_per_sec > 0 or self.rw_mbytes_per_sec > 0 or self.r_mbytes_per_sec > 0 or self.w_mbytes_per_sec > 0)
