@@ -336,14 +336,24 @@ def spdk_process_start(body: SPDKParams):
         spdk_process_kill(query)
 
     node_prepration_job_name = "snode-spdk-job-"
+    node_prepration_core_name = "snode-spdk-core-isolate-"
     node_name = os.environ.get("HOSTNAME", "")
-
+    core_isolate = os.environ.get("CORE_ISOLATION", False)
+    if isinstance(core_isolate, str):
+       core_isolate = core_isolate.strip().lower() in ("true")
+    
     # limit the job name length to 63 characters
     k8s_job_name_length = len(node_prepration_job_name+node_name)
+    core_name_length = len(node_prepration_core_name+node_name)
     if k8s_job_name_length > 63:
         node_prepration_job_name += node_name[k8s_job_name_length-63:]
     else:
         node_prepration_job_name += node_name
+        
+    if core_name_length > 63:
+        node_prepration_core_name += node_name[core_name_length-63:]
+    else:
+         node_prepration_core_name += node_name
 
     logger.debug(f"deploying k8s job to prepare worker: {node_name}")
 
@@ -361,6 +371,7 @@ def spdk_process_start(body: SPDKParams):
             'RPC_PASSWORD': body.rpc_password,
             'HOSTNAME': node_name,
             'JOBNAME': node_prepration_job_name,
+            'CORE_JOBNAME': node_prepration_core_name,
             'NAMESPACE': namespace,
             'FDB_CONNECTION': body.fdb_connection,
             'SIMPLYBLOCK_DOCKER_IMAGE': constants.SIMPLY_BLOCK_DOCKER_IMAGE,
@@ -390,6 +401,27 @@ def spdk_process_start(body: SPDKParams):
         )
         logger.info(f"Job deleted: '{job_resp.metadata.name}' in namespace '{namespace}")
 
+        if core_isolate:
+            core_template = env.get_template('storage_core_isolation.yaml.j2')
+            core_yaml = yaml.safe_load(core_template.render(values))
+            batch_v1 = core_utils.get_k8s_batch_client()
+            core_resp = batch_v1.create_namespaced_job(namespace=namespace, body=core_yaml)
+            msg = f"Job created: '{core_resp.metadata.name}' in namespace '{namespace}"
+            logger.info(msg)
+
+            node_utils_k8s.wait_for_job_completion(core_resp.metadata.name, namespace)
+            logger.info(f"Job '{core_resp.metadata.name}' completed successfully")
+
+            batch_v1.delete_namespaced_job(
+                name=core_resp.metadata.name,
+                namespace=namespace,
+                body=V1DeleteOptions(
+                    propagation_policy='Foreground',
+                    grace_period_seconds=0
+                )
+            )
+            logger.info(f"Job deleted: '{core_resp.metadata.name}' in namespace '{namespace}")
+
         env = Environment(loader=FileSystemLoader(os.path.join(TOP_DIR, 'templates')), trim_blocks=True, lstrip_blocks=True)
         template = env.get_template('storage_deploy_spdk.yaml.j2')
         dep = yaml.safe_load(template.render(values))
